qPOTS: Batch Pareto Optimal Thompson sampling
=============================================

This repository contains the code for qPOTS, a multi-objective Bayesian optimization algorithm. 
Read the paper on arXiv: `here <https://arxiv.org/pdf/2310.15788>`_.

This repository is maintained by the Computational Complex Engineered Systems Design Laboratory (CSDL_) at Penn State.

.. _CSDL: https://sites.psu.edu/csdl/

================
Installing qPOTS
================



===============
Quick Start
===============

